@@ -271,8 +271,8 @@ class HistoryDB:
             if to_keep > 0:
                 logging.info("Removing all but last %s completed jobs from history", to_keep)
                 return self.execute(
-                    """DELETE FROM history WHERE status = ? AND id NOT IN ( 
-                        SELECT id FROM history WHERE status = ? ORDER BY completed DESC LIMIT ? 
+                    """DELETE FROM history WHERE status = ? AND id NOT IN (
+                        SELECT id FROM history WHERE status = ? ORDER BY completed DESC LIMIT ?
                     )""",
                     (Status.COMPLETED, Status.COMPLETED, to_keep),
                     save=True,
@@ -337,27 +337,24 @@ class HistoryDB:
         else:
             items = []
 
-        fetched_items = len(items)
-
         # Unpack the single line stage log
         # Stage Name is separated by ::: stage lines by ; and stages by \r\n
         items = [unpack_history_info(item) for item in items]
 
-        return items, fetched_items, total_items
+        return items, total_items
 
-    def have_episode(self, series, season, episode):
+    def have_episode(self, series: str, season: str, episode: str) -> bool:
         """Check whether History contains this series episode"""
         total = 0
-        series = series.lower().replace(".", " ").replace("_", " ").replace("  ", " ")
         if series and season and episode:
-            pattern = "%s/%s/%s" % (series, season, episode)
+            pattern = "%s/%s/%s" % (series.lower(), season, episode)
             if self.execute(
                 """SELECT COUNT(*) FROM History WHERE series = ? AND STATUS != ?""", (pattern, Status.FAILED)
             ):
                 total = self.c.fetchone()["COUNT(*)"]
         return total > 0
 
-    def have_name_or_md5sum(self, name, md5sum):
+    def have_name_or_md5sum(self, name: str, md5sum: str) -> bool:
         """Check whether this name or md5sum is already in History"""
         total = 0
         if self.execute(
@@ -479,7 +476,7 @@ def build_history_info(nzo, workdir_complete="", postproc_time=0, script_output=
     # Analyze series info only when job is finished
     series = ""
     if series_info:
-        seriesname, season, episode, _ = sabnzbd.newsunpack.analyse_show(nzo.final_name)
+        seriesname, season, episode = sabnzbd.newsunpack.analyse_show(nzo.final_name)[:3]
         if seriesname and season and episode:
             series = "%s/%s/%s" % (seriesname.lower(), season, episode)
 
@@ -507,7 +504,7 @@ def build_history_info(nzo, workdir_complete="", postproc_time=0, script_output=
         nzo.bytes_downloaded,
         series,
         nzo.md5sum,
-        nzo.password,
+        nzo.correct_password,
     )
 
 
